import {
  joinLogStrings,
  useLevelFilter,
  useNamespaceFilter
} from "./chunk-AWQTENOU.js";
import {
  LogLevelError,
  LogLevelInfo,
  LogLevelWarn
} from "./chunk-E6MPGGAE.js";
import {
  getGlobalConsole
} from "./chunk-MIZOLME5.js";

// src/common/log/log-console.ts
function LoggerConsoleHandler(opt = {}) {
  const {
    level = void 0,
    filter = void 0
    // colors = true,
    // levelHelper = false,
    // nameBrackets = true,
    // padding = 16,
  } = opt;
  const matchesNamespace = useNamespaceFilter(filter);
  const matchesLevel = useLevelFilter(level);
  const originalConsole = getGlobalConsole();
  return (msg) => {
    if (!matchesLevel(msg.level))
      return;
    if (!matchesNamespace(msg.name))
      return;
    const name = msg.name ? `[${msg.name}]` : "";
    switch (msg.level) {
      case LogLevelInfo:
        originalConsole.info(...joinLogStrings(`I|*   ${name}`, ...msg.messages));
        break;
      case LogLevelWarn:
        originalConsole.warn(...joinLogStrings(`W|**  ${name}`, ...msg.messages));
        break;
      case LogLevelError:
        originalConsole.error(...joinLogStrings(`E|*** ${name}`, ...msg.messages));
        break;
      default:
        originalConsole.debug(...joinLogStrings(`D|    ${name}`, ...msg.messages));
        break;
    }
  };
}

export {
  LoggerConsoleHandler
};
//# sourceMappingURL=chunk-E5KC2C3C.js.map