import "../chunk-WHC33HV6.js";
import "../chunk-IQFZHKL7.js";
import "../chunk-L7ERHMSS.js";
import "../chunk-RI4H2YNF.js";
import "../chunk-AJ3WFXQE.js";
import "../chunk-CRXTUPG7.js";
import "../chunk-CJLX6OUU.js";
import "../chunk-LDQLGI37.js";
import "../chunk-MPAXUMZ5.js";
import "../chunk-GMDZVSOA.js";
import "../chunk-PJDBG5VS.js";
import "../chunk-LYDX5BFI.js";
import "../chunk-CZZTWTGB.js";
import {
  useDefer,
  useDispose
} from "../chunk-CLQAILWG.js";
import "../chunk-TSCDX4AS.js";
import "../chunk-OKF7THJ6.js";
import {
  DefaultLogger
} from "../chunk-SMUTBZJI.js";
import "../chunk-RJL5WFWU.js";
import "../chunk-E5KC2C3C.js";
import "../chunk-D6B6MYVG.js";
import "../chunk-RG6OSZW5.js";
import "../chunk-AWQTENOU.js";
import "../chunk-E6MPGGAE.js";
import "../chunk-I45WP5PM.js";
import "../chunk-MIZOLME5.js";
import "../chunk-5HGOJFJL.js";
import "../chunk-CFICINSP.js";
import "../chunk-UHTVWILC.js";
import "../chunk-T7PU5CTZ.js";
import "../chunk-XSB2WAW2.js";
import "../chunk-NYCGHEIN.js";
import "../chunk-AS5LR4AI.js";
import "../chunk-5Y3HYG6B.js";
import "../chunk-KQSQJAHU.js";
import "../chunk-X2DIUKLP.js";
import "../chunk-2HWPZ6ZE.js";
import "../chunk-XOOIUMF2.js";
import "../chunk-73CVRDI7.js";
import "../chunk-FL5CT6MC.js";
import "../chunk-HLRQ5H3N.js";
import "../chunk-M6LJR6SZ.js";
import "../chunk-NXVGWT4R.js";
import "../chunk-DGP32WEQ.js";
import "../chunk-O4U55KGC.js";
import "../chunk-4XPO57AQ.js";
import "../chunk-ACZDEHYB.js";
import {
  sleep
} from "../chunk-FSDCRQB3.js";
import "../chunk-YEEGQOIW.js";
import "../chunk-AEBHR4XF.js";
import "../chunk-IZT6OHMS.js";
import "../chunk-GY34N3KU.js";
import "../chunk-NS4INNCL.js";
import "../chunk-TYWNSO7K.js";
import "../chunk-ZMFW3O35.js";
import "../chunk-R6KULE2F.js";
import "../chunk-7NSVDPHN.js";
import "../chunk-VVNSHVPQ.js";
import "../chunk-6GHO7LQW.js";

// src/common/dispose-defer.spec.ts
var log = DefaultLogger("dispose-test");
describe("dispose", () => {
  it("should dispose correctly", async () => {
    const disposeCalls = [];
    const dispose = useDispose("a");
    const y = dispose.track({
      dispose() {
        disposeCalls.push(1);
      }
    });
    dispose.track(() => {
      disposeCalls.push(2);
    });
    const x = {
      async dispose() {
        disposeCalls.push(3);
      }
    };
    dispose.track(x);
    dispose.track();
    dispose.track(async () => {
      disposeCalls.push(4);
    });
    expect(disposeCalls).toEqual([]);
    expect(dispose.getSize()).toEqual(4);
    await dispose.untrack(x);
    expect(disposeCalls).toEqual([3]);
    expect(dispose.getSize()).toEqual(3);
    await dispose.untrack(x);
    expect(disposeCalls).toEqual([3]);
    expect(dispose.getSize()).toEqual(3);
    y?.();
    y?.();
    await dispose.untrack(x);
    expect(disposeCalls).toEqual([3, 1]);
    expect(dispose.getSize()).toEqual(2);
    await dispose.dispose();
    expect(disposeCalls).toEqual([3, 1, 4, 2]);
    expect(dispose.getSize()).toEqual(0);
    await dispose();
    expect(disposeCalls).toEqual([3, 1, 4, 2]);
    expect(dispose.getSize()).toEqual(0);
  });
  it("should be a fancy dispose itself", () => {
    let x = 1;
    class Some {
      constructor() {
        this.dispose = useDispose(log);
        this.dispose.track(() => {
          x = 2;
        });
      }
    }
    const obj = new Some();
    expect(x).toBe(1);
    void obj.dispose();
    expect(x).toBe(2);
  });
  it("should defer lifo", async () => {
    const stack = [];
    const defer = useDefer({ mode: "lifo" });
    defer.add(() => stack.push("a"));
    defer.add(() => stack.push("b"));
    defer.add(() => stack.push("c"));
    expect(stack).toEqual([]);
    void defer(true);
    expect(stack).toEqual(["c", "b", "a"]);
  });
  it("should defer fifo", async () => {
    const stack = [];
    const defer = useDefer({ mode: "fifo" });
    defer.add(() => stack.push("a"));
    defer.add(async () => stack.push("b"));
    defer.add(() => stack.push("c"));
    expect(stack).toEqual([]);
    await defer();
    expect(stack).toEqual(["a", "b", "c"]);
  });
  it("should dispose sync", async () => {
    const stack = [];
    const dispose = useDispose();
    dispose.add(() => stack.push("a"));
    dispose.add(() => stack.push("b"));
    dispose.add(() => stack.push("c"));
    expect(stack).toEqual([]);
    await dispose(true);
    expect(stack).toEqual(["c", "b", "a"]);
  });
  it("should dispose sync 2", async () => {
    const stack = [];
    const dispose = useDispose();
    dispose.add(() => stack.push("a"));
    dispose.add(() => stack.push("b"));
    dispose.add(async () => {
      await sleep(1);
      stack.push("c");
    });
    expect(stack).toEqual([]);
    expect(dispose.sync).toThrowError();
  });
});
//# sourceMappingURL=dispose-defer.spec.js.map